@@ -1,39 +1,39 @@
 package Dist::Zilla::Plugin::ReadmeFromPod;
 BEGIN {
-  $Dist::Zilla::Plugin::ReadmeFromPod::VERSION = '0.11';
+  $Dist::Zilla::Plugin::ReadmeFromPod::AUTHORITY = 'cpan:AVAR';
+}
+BEGIN {
+  $Dist::Zilla::Plugin::ReadmeFromPod::VERSION = '0.12';
 }
 
 use Moose;
 use Moose::Autobox;
 use IO::Handle;
-use File::Temp qw< tempdir tempfile >;
+use Encode qw( encode );
+
 with 'Dist::Zilla::Role::InstallTool';
 
 sub setup_installer {
   my ($self, $arg) = @_;
 
   require Dist::Zilla::File::InMemory;
-
-  my $dir = tempdir( CLEANUP => 1 );
-  my ($out_fh, $filename) = tempfile( DIR => $dir );
-
+  
   my $mmcontent = $self->zilla->main_module->content;
 
   require Pod::Text;
   my $parser = Pod::Text->new();
-  $parser->output_fh( $out_fh );
+  $parser->output_string( \my $input_content );
   $parser->parse_string_document( $mmcontent );
-
-  $out_fh->sync();
-  close $out_fh;
-
-  # Do *not* convert this to something that doesn't use open() for
-  # cleverness, that breaks UTF-8 pod files.
-  open(my $fh, "<", $filename) or die "Can't open file '$filename'";
-  my $content = do { local $/; <$fh> };
-  close $fh;
+  
+  my $content;
+  if( defined $parser->{encoding} ){ 
+    $content = encode( $parser->{encoding} , $input_content );
+  } else { 
+     $content = $input_content; 
+  }
 
   my $file = $self->zilla->files->grep( sub { $_->name =~ m{README\z} } )->head;
+
   if ( $file ) {
     $file->content( $content );
     $self->zilla->log("Override README from [ReadmeFromPod]");
